@@ -9,7 +9,7 @@ import glob
 import time
 
 
-__version__ = '0.0.15'
+__version__ = '0.0.17'
 
 samples_s3_folder = 'pypi_samples'
 inference_samples_s3_folder = 'pypi_toinfer'
@@ -104,9 +104,8 @@ class client():
         print("Training a model...\n")
         
         payload = {
-            "event_id": task_id,
-            "camera_id": 'nil',
-            "event_name": 'nil',
+            "task_id": task_id,
+            "task_name": 'nil',
             "confidence_threshold": confidence_threshold,
             "n_positive": n_positive,
             "n_negative": n_negative,
@@ -121,7 +120,7 @@ class client():
         resp_json = json.loads(resp.content)
         
         result = {}
-        result['task_id'] = resp_json['event_id'] 
+        result['task_id'] = resp_json['task_id'] 
         result['message'] = resp_json['message']
         result['success'] = resp_json['success']
         result['n_positive_samples'] = n_positive
@@ -160,7 +159,8 @@ class client():
             "update_model": False,
             "force_late_infer": True,
             "inference_samples_s3_bucket": 'vo-fsl-demo2',
-            "inference_samples_s3_folder": inference_samples_s3_folder
+            "inference_samples_s3_folder": inference_samples_s3_folder,
+            "model_timestamp": 0
         }
                 
         resp_json = {}
